# Normalizcia dtovho sboru

library(affy)
library(affydata)
library(limma)
library(rma)
require(affy)
require(affyPLM)

#Nactanie CEL sborov do objektu AffyBatch
Xraw = ReadAffy(celfile.path="Raw/")
str(Xraw)
nm   = sampleNames(Xraw)
ns   = length(nm)

sampleInfo=read.csv("sampleInfo.csv",header=T, row.names=1)


# Nzvy cipov upravme, odstrnime ".CEL":
nm = unlist(strsplit(sampleNames(Xraw), split=".", fixed=TRUE))[seq(1,2*ns,2)]
sampleNames(Xraw) = substring(nm, 11, nchar(nm))

sampleInfo = sampleInfo[sampleNames(Xraw),]

### Kontrola kvality ###

# kontrola kvality sondy ESR1
par(mfrow=c(1,2))
matplot(pm(Xraw,"205225_at"), type="l", ylab="PM intensita sondy", xlab="Sada sond 205225_at", las=1, col=as.numeric(sampleInfo$ER_status), main="ESR1, PM", ylim=c(0,13000))
 matplot(mm(Xraw,"205225_at"), type="l", ylab="MM intensita sondy", xlab="Sada sond 205225_at", las=1, col=as.numeric(sampleInfo$ER_status), main="ESR1, MM", ylim=c(0,13000))


# histogram
hist(Xraw)


# Vykreslme MA plot
par(mfrow=c(3,4))
MAplot(Xraw)


# s pouitm funkcie PLM poctame NUSE hodnoty
pset = fitPLM(Xraw)
s = nuse(pset, type="stats") 

W = s["median",]>1.04
E = s["median",]>1.06

# Vykreslme NUSE hodnoty pre kad cip
NUSE(pset)

# Vykreslme obrzky cipov
image(pset)

#Vykreslme MA plot 
par(mfrow=c(5,4))
MAplot(pset)


# vyberme len cipy s nzkou hodnotou NUSE

if (sum(E) > 0)
        Xraw = Xraw[,-which(E)]                          
save(Xraw, file="raw.rdata")

MAplot(Xraw)

# Normalizujeme dta s pomocou RMA
Xnrm      = rma(Xraw)
save(Xnrm, file='rma.rdata')

par(mfrow=c(5,4))
MAplot(Xnrm)

# extrahujeme expresn hodnoty
X         = t(exprs(Xnrm))             # keep genes by columns
X[1:5,1:5]
save(X, file=expr-rma.rdata')

# suamarizujeme na EntrezGene podla najvariabilnejsej probeset

anotace = read.csv("GPL96-15653.txt", header=TRUE, skip=16, sep="\t")
rownames(anotace) = anotace[,1]

str(anotace)

# vyber najvariabilnejsej probeset v ramci EntrezGeneID

pst.var  = apply(X,2,sd)
pst.var[1:5]
which.EID.var = tapply(pst.var,anotace[names(pst.var),"ENTREZ_GENE_ID"],FUN=function(x) names(which.max(x)))
which.EID.var[1:5]
X_EID = X[,which.EID.var]
colnames(X_EID) = as.character(names(which.EID.var))
X_EID[1:4,1:4]
save(X_EID, file="X_EID.rdata")

#vyber najvariabilnejsej probeset v ramci Gene Symbol

which.GS.var = tapply(pst.var,anotace[names(pst.var),"Gene.Symbol"],FUN=function(x) names(which.max(x)))
which.GS.var[1:5]

X_GS = X[,which.GS.var]
colnames(X_GS) = as.character(names(which.GS.var))
X_GS[1:4,1:4]
save(X_GS, file="X_GS.rdata")




















